==> uilite-1.0.64.tgz: package/webpack.config.js <==
const path = require('path');
let webpack=require("webpack");
let fs=require("fs");
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
//let staticPath=[{directory:path.join(currentDir,"public")}]
function getProjectData(projectName){
  let currentDir=process.cwd();

  let obj={
   entry:path.join(currentDir,"/src/main.ts"),
   buildPath:path.join(currentDir, 'build'),
   staticDir:"public",
   staticPath:[{directory:path.join(currentDir,"public")}],
   template:path.join(currentDir,'build/index.html'),
   port:"5502", 
   bundleFileName:"bundle.js",
   env:path.join(currentDir,"public/.env")
  } 
  if(projectName){
   let projectJson=JSON.parse(fs.readFileSync(process.cwd()+"/project.json"));
   let projectData=projectJson[projectName];
    if(projectData?.entry){
     obj.entry=path.join(currentDir,projectData.entry);
    }
    if(projectData?.build_path){
     obj.buildPath=path.join(currentDir, projectData.build_path)
    }
    if(projectData?.static_path){
     obj.template= path.join(currentDir,projectData.static_path+'/index.html')
     obj.staticDir=path.join(currentDir,projectData.static_path)
     obj.staticPath=[{directory:path.join(currentDir,projectData.static_path),publicPath:"/"}]
    }
    if(projectData?.port){
      obj.port=projectData.port;
    }
    if(projectData?.bundel_file_name){
      obj.bundleFileName=projectData.bundel_file_name
    }
    if(projectData?.env){
      obj.env=path.join(currentDir,projectData.env);
    }
  }
 return obj;
}
module.exports= wenv => {
  let {entry,buildPath,port,staticDir,staticPath,template,bundleFileName,env} =getProjectData(wenv.project);
  let envObj="{}"
  try{
    envObj=fs.readFileSync(env,"utf-8");
  }
  catch(err){
    envObj="{}"
  }
 return ({
 mode:"production",
 entry: entry,
 devtool: 'source-map',
  module: {
    rules: [
      {
        test: /\.ts?$/,
        use: 'ts-loader',
        exclude: /node_modules/,
      },
      {
        test: /\.html$/i,
        rules:[{
              loader: "val-loader",
              options: {
                executableFile: path.resolve(
                  __dirname,
                  "importHtml.js"
                ),
              },
        }]
      },
      {
             test: /\.(s(a|c)ss)$/,
             use: [MiniCssExtractPlugin.loader,'css-loader', 'sass-loader']
      },
      {
        test: /\.(woff|woff2|eot|ttf|svg|jpg|png)$/,
        use: {
          loader: 'url-loader',
        },
       },
    ],
  },
  resolve: {
    extensions: [ '.tsx', '.ts', '.js',".html" ],
  },
  output: {
    publicPath: "/",
    filename: bundleFileName,
    path: buildPath,
  },
  devServer:{
    hot:true,
    open:true,
    static: staticPath,
    compress:true,
    port:port,
    historyApiFallback: true
    },
  plugins: [
    new webpack.DefinePlugin({
      "process.env": envObj
    }),
    new MiniCssExtractPlugin(),
    new HtmlWebpackPlugin({
      inject: true,
      template: template,
    }),
  ]
})

};

==> uilite-1.0.74.tgz: package/webpack.config.js <==
const path = require('path');
let webpack=require("webpack");
let fs=require("fs");
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
//let staticPath=[{directory:path.join(currentDir,"public")}]
function getProjectData(projectName){
  let currentDir=process.cwd();

  let obj={
   entry:path.join(currentDir,"/src/main.ts"),
   buildPath:path.join(currentDir, 'build'),
   staticDir:"public",
   staticPath:[{directory:path.join(currentDir,"public")}],
   template:path.join(currentDir,'build/index.html'),
   port:"5502", 
   bundleFileName:"bundle.js",
   env:path.join(currentDir,"public/.env"),
   html_file_name:"index.html"
  } 
  if(projectName){
   let projectJson=JSON.parse(fs.readFileSync(process.cwd()+"/project.json"));
   let projectData=projectJson[projectName];
   obj.html_file_name=(projectData?.html_file_name || 'index.html');
    if(projectData?.entry){
     obj.entry=path.join(currentDir,projectData.entry);
    }
    if(projectData?.build_path){
     obj.buildPath=path.join(currentDir, projectData.build_path)
    }
    if(projectData?.static_path){
     obj.template= path.join(currentDir,projectData.static_path+'/'+obj.html_file_name)
     obj.staticDir=path.join(currentDir,projectData.static_path)
     obj.staticPath=[{directory:path.join(currentDir,projectData.static_path),publicPath:"/"}]
    }
    if(projectData?.port){
      obj.port=projectData.port;
    }
    if(projectData?.bundel_file_name){
      obj.bundleFileName=projectData.bundel_file_name
    }
    if(projectData?.env){
      obj.env=path.join(currentDir,projectData.env);
    }
  }
 return obj;
}
module.exports= wenv => {
  let {entry,buildPath,port,staticDir,staticPath,template,bundleFileName,env,html_file_name} =getProjectData(wenv.project);
  let envObj="{}"
  try{
    envObj=fs.readFileSync(env,"utf-8");
  }
  catch(err){
    envObj="{}"
  }
 return ({
 mode:"production",
 entry: entry,
 devtool: 'source-map',
  module: {
    rules: [
      {
        test: /\.ts?$/,
        use: 'ts-loader',
        exclude: /node_modules/,
      },
      {
        test: /\.html$/i,
        rules:[{
              loader: "val-loader",
              options: {
                executableFile: path.resolve(
                  __dirname,
                  "importHtml.js"
                ),
              },
        }]
      },
      {
             test: /\.(s(a|c)ss)$/,
             use: [MiniCssExtractPlugin.loader,'css-loader', 'sass-loader']
      },
      {
        test: /\.(woff|woff2|eot|ttf|svg|jpg|png)$/,
        use: {
          loader: 'url-loader',
        },
       },
    ],
  },
  resolve: {
    extensions: [ '.tsx', '.ts', '.js',".html" ],
  },
  output: {
    publicPath: "/",
    filename: bundleFileName,
    path: buildPath,
  },
  devServer:{
    hot:true,
    open:true,
    static: staticPath,
    compress:true,
    port:port,
    historyApiFallback: true
    },
  plugins: [
    new webpack.DefinePlugin({
      "process.env": envObj
    }),
    new MiniCssExtractPlugin(),
    new HtmlWebpackPlugin({
      filename:html_file_name,
      inject: true,
      template: template,
    }),
  ]
})

};
